@@ -11,7 +11,7 @@ use String::Perl::Warnings qw(is_warning);
 use Module::Pluggable search_path => 'POE::Component::SmokeBox::Backend', sub_name => 'backends', except => 'POE::Component::SmokeBox::Backend::Base';
 use vars qw($VERSION);
 
-$VERSION = '0.26';
+$VERSION = '0.28';
 
 my $GOT_KILLFAM;
 my $GOT_PTY;
@@ -226,7 +226,7 @@ sub _wheel_stdout {
   $self->{_wheel_time} = time();
   push @{ $self->{_wheel_log} }, $input;
   warn $input, "\n" if $self->{debug} or $ENV{PERL5_SMOKEBOX_DEBUG};
-  if ( $self->_detect_loop( $input ) ) {
+  if ( $self->_detect_loop( $input, 'stdout' ) ) {
     $self->{excess_kill} = 1;
     $poe_kernel->yield( '_wheel_kill', 'Killing current run due to detection of looping output' );
   }
@@ -240,7 +240,7 @@ sub _wheel_stderr {
   push @{ $self->{_wheel_log} }, $input;
   warn $input, "\n" if $self->{debug} or $ENV{PERL5_SMOKEBOX_DEBUG};
   return if is_warning($input);
-  if ( $self->_detect_loop( $input ) ) {
+  if ( $self->_detect_loop( $input, 'stderr' ) ) {
     $self->{excess_kill} = 1;
     $poe_kernel->yield( '_wheel_kill', 'Killing current run due to detection of looping output' );
   }
@@ -250,11 +250,13 @@ sub _wheel_stderr {
 sub _detect_loop {
   my $self = shift;
   my $input = shift || return;
+  my $handle = shift || 'stdout';
   return if $self->{_loop_detect};
   return if $input =~ /^\[(MSG|ERROR)\]/;
   my $digest = md5_hex( $input );
-  $self->{_digests}->{ $digest }++;
-  return unless ++$self->{_digests}->{ $digest } > 300;
+  my $weighting = $handle eq 'stdout' ? 10 : 1;
+  $self->{_digests}->{ $digest } += $weighting;
+  return unless ++$self->{_digests}->{ $digest } > 3000;
   return $self->{_loop_detect} = 1;
 }
 
